@@ -94,7 +94,7 @@ define([
         this.loadVariables();
 
         this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/variables.css");
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "file_io/variables.css");
 
         // load variables on refresh
         $(this.wrapSelector('#vp_varRefresh')).click(function(event) {
@@ -132,7 +132,7 @@ define([
             , 'str', 'int', 'float', 'bool', 'dict', 'list', 'tuple'
         ];
 
-        var tagTable = this.wrapSelector('#vp_variableBox table');
+        var tagTable = this.wrapSelector('#vp_var_variableBox table');
 
         // 변수 정보 표시
         var tagDetailTable = this.wrapSelector("#vp_varDetailTable");
@@ -143,8 +143,9 @@ define([
         
         // HTML 구성
         pdGen.vp_searchVarList(types, function(result) {
-            var jsonVars = result.replace(/'/gi, `"`);
-            var varList = JSON.parse(jsonVars);
+            // var jsonVars = result.replace(/'/gi, `"`);
+            // var varList = JSON.parse(jsonVars);
+            var varList = JSON.parse(result);
 
             // table 에 변수목록 추가
             varList.forEach(varObj => {
@@ -230,18 +231,17 @@ define([
      * @param {boolean} exec 실행여부
      */
     VariablePackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
-        
-        // 생성된 것 표시
-        sbCode.appendLine(`# Auto-Generated by VisualPython`);
 
         // TODO: 변수 내용 조회
-        var selectedVariable = $(this.wrapSelector('#vp_variableBox table tr.selected'));
-        if (selectedVariable == undefined) return "BREAK_RUN"; // 코드 생성 중 오류 발생
-        
-        sbCode.appendFormat('{0}', selectedVariable.attr('data-var-name'));
+        var selectedVariable = $(this.wrapSelector('#vp_var_variableBox table tr.selected'));
+        if (selectedVariable) {
+            var varName = selectedVariable.attr('data-var-name');
+            if (varName) {
+                sbCode.appendFormat('{0}', varName);
+            }
+        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
