@@ -109,10 +109,7 @@ define([
         var sbPageContent = new sb.StringBuilder();
         var sbTagString = new sb.StringBuilder();
 
-        // prefix code 입력 영역
-        sbPageContent.appendLine(this.createPrefixCode());
-        // sbPageContent.appendLine(this.createManualCode(vpConst.API_OPTION_PREFIX_CAPTION, vpConst.API_OPTION_PREFIX_CODE_ID, vpConst.PREFIX_CODE_SIGNATURE));
-        // this.getPrefixCode(); this.setPrefixCode("value"); // prefix code 접근
+        
 
         // 필수 옵션 테이블 레이아웃
         var tblLayoutRequire = this.createVERSimpleLayout("25%");
@@ -123,7 +120,7 @@ define([
 
         sbTagString.clear();
         sbTagString.appendFormat('<input type="text" id="{0}" class="{1}" />', 'vp_pyReturn', 'vp-input l');
-        tblLayoutRequire.addRow("Return Variable", sbTagString.toString());
+        tblLayoutRequire.addRow("Return to", sbTagString.toString());
         
         // 필수 옵션 영역 (아코디언 박스)
         var accBoxRequire = this.createOptionContainer(vpConst.API_REQUIRE_OPTION_BOX_CAPTION);
@@ -141,9 +138,7 @@ define([
 
         // sbPageContent.appendLine(accBoxAdditional.toTagString());
 
-        // postfix code 입력 영역
-        sbPageContent.appendLine(this.createPostfixCode());
-        
+                
         this.setPage(sbPageContent.toString());
         sbPageContent.clear();
     }
@@ -156,20 +151,13 @@ define([
      */
     PythonCommon.prototype.generateCode = function(addCell = false, exec = false) {
         var code = new sb.StringBuilder();
-        var prefixCode = this.getPrefixCode();
-        if (prefixCode != '') {
-            code.appendLine(prefixCode);
-        }
+        
         var returnVar = $(this.wrapSelector('#vp_pyReturn')).val();
         if (returnVar != '') {
             code.appendFormat("{0} = ", returnVar);
         }
         code.appendFormat('abs({0})', $(this.wrapSelector('#vp_pyAbs')).val());
-        var postfixCode = this.getPostfixCode();
-        if (postfixCode != '') {
-            code.appendLine();
-            code.append(this.getPostfixCode());
-        }
+        
 
         if (addCell) {
             this.cellExecute(code.toString(), exec);
